summaryrefslogtreecommitdiffstats
path: root/parts/filelist/projectviewpart.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filelist/projectviewpart.h')
-rw-r--r--parts/filelist/projectviewpart.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/filelist/projectviewpart.h b/parts/filelist/projectviewpart.h
index 392a9cdf..72c6efcd 100644
--- a/parts/filelist/projectviewpart.h
+++ b/parts/filelist/projectviewpart.h
@@ -18,8 +18,8 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#ifndef KDEVPROJECTVIEW_H
-#define KDEVPROJECTVIEW_H
+#ifndef TDEVPROJECTVIEW_H
+#define TDEVPROJECTVIEW_H
#include "fileinfo.h"
@@ -27,7 +27,7 @@
#include <tqmap.h>
#include <tqguardedptr.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
#include <kurl.h>
@@ -53,7 +53,7 @@ this is a reimplementation of the project views in Quanta
@TODO save html parts too
FIXME at project open I get the default view and the open files at last close
*/
-class ProjectviewPart: public KDevPlugin
+class ProjectviewPart: public TDevPlugin
{
Q_OBJECT
@@ -66,7 +66,7 @@ public:
ProjectviewPart(TQObject *parent, const char *name, const TQStringList &args);
~ProjectviewPart();
// reimplemented from KDevPlugin
void restorePartialProjectSession(const TQDomElement * el);
void savePartialProjectSession(TQDomElement * el);
@@ -66,7 +66,7 @@ public:
ProjectviewPart(TQObject *parent, const char *name, const TQStringList &args);
~ProjectviewPart();
- // reimplemented from KDevPlugin
+ // reimplemented from TDevPlugin
void restorePartialProjectSession(const TQDomElement * el);
void savePartialProjectSession(TQDomElement * el);